ziggy.GraphReduce.PageRank_mapper

Package ziggy :: Package GraphReduce :: Module PageRank_mapper |
[hide private]
[frames] | no frames]

# Module PageRank_mapper

source code

Created on Aug 18, 2010

Author: dwmclary

Classes | [hide private]
| PRNode

Functions | [hide private]
read_adjacency(file, comment=`'``#``'`, sep=None, mass=None) | source code
main(rank_mass) | source code

Variables | [hide private]
| __package__ = ``'``ziggy.GraphReduce``'``